@@ -19,83 +19,6 @@ find.transitions <- function(y) {
 
 }
 
-#' Combine too-short Sojourns
-#'
-#' @param durations durations of a set of Sojourns
-#' @param short duration cutoff that defines a too-short Sojourn
-#'
-#' @keywords internal
-#'
-combine.sojourns <- function(durations, short) {
-
-  # combine too short sojourns.
-
-  # FIXME:
-  # I (IJS) think that this and find.transitions() are the weak point of the
-  # method. Much improvement could be accomplished by making this smarter.
-  # But my efforts to improve it haven't been that effective. If you have
-  # lots of free-living training data and want to make SIP/Sojourns better,
-  # focus on this!
-
-  # Handle the case where the first or last sojourn is too short
-  bool.too.short <- durations<short
-  # If all sojourn durations are too short, glom them all.
-  if(all(bool.too.short))
-    return(sum(durations))
-  counter.1 <- which.min(bool.too.short)
-  counter.2 <- length(durations)+1-which.min(rev(bool.too.short))
-  durations <- c(sum(durations[1:counter.1]),
-    durations[(counter.1+1):(counter.2-1)],
-    sum(durations[counter.2:length(durations)]))
-
-  #   combine too short sojourns with neighboring sojourn.
-  #   this loop repeats until there are no more too short sojourns
-
-  repeat {
-
-    sojourns <- 1:length(durations)
-    too.short <- sojourns[durations<short]
-    ts <- length(too.short)
-
-    if(ts==0)
-      break
-
-    # now deal with all other too short sojourns
-    #   right now i combine too short sojourns with its neighbor that was shorter in duration (e.g. first neighbor = 60 seconds long and second neighbor = 300 seconds long, it gets combined with first neighbor)
-
-    durations.first.neighbors <- durations[too.short-1]
-    durations.second.neighbors <- durations[too.short+1]
-
-    too.short.inds.first <- too.short[
-      durations.first.neighbors <=
-        durations.second.neighbors
-    ]
-    too.short.inds.second <- too.short[
-      durations.first.neighbors >
-        durations.second.neighbors
-    ]
-
-    sojourns[too.short.inds.first] <- too.short.inds.first-1
-    sojourns[too.short.inds.second] <- too.short.inds.second+1
-
-    # deal with instances where need to combine more than 2 sojourns - i.e.
-    # short sojourn became first neighbor, and then sojourn before first
-    # neighbor also becomes that sojourn via second neighbor grouping - want all
-    # 3 of these sojourns to be combined.
-
-    inds.order <- (1:(length(sojourns)-1))[diff(sojourns)<0]
-    sojourns[inds.order+1] <- sojourns[inds.order]
-
-    # get new durations now that sojourns are combined
-
-    durations <- as.vector(tapply(durations,sojourns,sum))
-
-  }
-
-  return(durations)
-
-}
-
 #' Check the formatting of a data frame for use in the SIP pipeline
 #'
 #' @param frame The data frame to check
